## @knitr Setup
library(tidyverse)
library(tidymodels)
library(skimr)
library(readxl)
WageDataOrg <- read_excel("WageDataModifRTalk.xlsx", 
                                 sheet = "DataClean")

NOrg=nrow(WageDataOrg)
## @knitr Summarize
DataInfo=skim(WageDataOrg)


## @knitr CleanAndProcess

RecipeCl=recipe(Wage~Educ+Exper+Tenure+NonWhite+Sex, data=WageDataOrg)%>% 
  step_dummy(all_nominal()) %>% 
  step_meanimpute(Educ) %>% 
  step_medianimpute(NonWhite_Yes) %>% 
  step_knnimpute(Tenure) %>% 
  step_naomit(Sex_Male) %>% 
  prep()

WageData=juice(RecipeCl)

DataInfoNew=skim(WageData)

N=nrow(WageData)

## @knitr Visualization

ScatPlot=ggplot(aes(x=Educ,y=Wage),data=WageData)+
  geom_point()+
  ggtitle("Scatter Plot for Wage and Education", "produced for R workshop")

ScatPlot=ScatPlot+
         geom_smooth(method="lm")

BoxPlot=ggplot(aes(x=factor(Sex_Male),y=Wage),data =  WageData) + 
        geom_boxplot()+
        ggtitle("Box Plot for Wage for Sex", "(male = 1)")

HistPlot=ggplot(aes(x=Wage), data=WageData) +
  geom_histogram(color="blue",fill="red")+
  ggtitle("Histogram for Wage", "(beautified with colors)")


## @knitr VarTest
var.test(Wage~Sex_Male,WageData)

## @knitr tTest
t.test(Wage~Sex_Male,WageData, var.equal=FALSE)

## @knitr Regression
ModelLm0=lm(Wage~., data=WageData)

ModelLmFinal=lm(Wage~.-NonWhite_Yes, data=WageData)

